from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as _subaccount_pb2
from v4_proto.dydxprotocol.vault import params_pb2 as _params_pb2
from v4_proto.dydxprotocol.vault import share_pb2 as _share_pb2
from v4_proto.dydxprotocol.vault import vault_pb2 as _vault_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryParamsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryParamsResponse(_message.Message):
    __slots__ = ("default_quoting_params", "operator_params")
    DEFAULT_QUOTING_PARAMS_FIELD_NUMBER: _ClassVar[int]
    OPERATOR_PARAMS_FIELD_NUMBER: _ClassVar[int]
    default_quoting_params: _params_pb2.QuotingParams
    operator_params: _params_pb2.OperatorParams
    def __init__(self, default_quoting_params: _Optional[_Union[_params_pb2.QuotingParams, _Mapping]] = ..., operator_params: _Optional[_Union[_params_pb2.OperatorParams, _Mapping]] = ...) -> None: ...

class QueryVaultRequest(_message.Message):
    __slots__ = ("type", "number")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    type: _vault_pb2.VaultType
    number: int
    def __init__(self, type: _Optional[_Union[_vault_pb2.VaultType, str]] = ..., number: _Optional[int] = ...) -> None: ...

class QueryVaultResponse(_message.Message):
    __slots__ = ("vault_id", "subaccount_id", "equity", "inventory", "vault_params", "most_recent_client_ids")
    VAULT_ID_FIELD_NUMBER: _ClassVar[int]
    SUBACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    EQUITY_FIELD_NUMBER: _ClassVar[int]
    INVENTORY_FIELD_NUMBER: _ClassVar[int]
    VAULT_PARAMS_FIELD_NUMBER: _ClassVar[int]
    MOST_RECENT_CLIENT_IDS_FIELD_NUMBER: _ClassVar[int]
    vault_id: _vault_pb2.VaultId
    subaccount_id: _subaccount_pb2.SubaccountId
    equity: bytes
    inventory: bytes
    vault_params: _params_pb2.VaultParams
    most_recent_client_ids: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, vault_id: _Optional[_Union[_vault_pb2.VaultId, _Mapping]] = ..., subaccount_id: _Optional[_Union[_subaccount_pb2.SubaccountId, _Mapping]] = ..., equity: _Optional[bytes] = ..., inventory: _Optional[bytes] = ..., vault_params: _Optional[_Union[_params_pb2.VaultParams, _Mapping]] = ..., most_recent_client_ids: _Optional[_Iterable[int]] = ...) -> None: ...

class QueryAllVaultsRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryAllVaultsResponse(_message.Message):
    __slots__ = ("vaults", "pagination")
    VAULTS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    vaults: _containers.RepeatedCompositeFieldContainer[QueryVaultResponse]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, vaults: _Optional[_Iterable[_Union[QueryVaultResponse, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryMegavaultTotalSharesRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryMegavaultTotalSharesResponse(_message.Message):
    __slots__ = ("total_shares",)
    TOTAL_SHARES_FIELD_NUMBER: _ClassVar[int]
    total_shares: _share_pb2.NumShares
    def __init__(self, total_shares: _Optional[_Union[_share_pb2.NumShares, _Mapping]] = ...) -> None: ...

class QueryMegavaultOwnerSharesRequest(_message.Message):
    __slots__ = ("address",)
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: str
    def __init__(self, address: _Optional[str] = ...) -> None: ...

class QueryMegavaultOwnerSharesResponse(_message.Message):
    __slots__ = ("address", "shares", "share_unlocks", "equity", "withdrawable_equity")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    SHARES_FIELD_NUMBER: _ClassVar[int]
    SHARE_UNLOCKS_FIELD_NUMBER: _ClassVar[int]
    EQUITY_FIELD_NUMBER: _ClassVar[int]
    WITHDRAWABLE_EQUITY_FIELD_NUMBER: _ClassVar[int]
    address: str
    shares: _share_pb2.NumShares
    share_unlocks: _containers.RepeatedCompositeFieldContainer[_share_pb2.ShareUnlock]
    equity: bytes
    withdrawable_equity: bytes
    def __init__(self, address: _Optional[str] = ..., shares: _Optional[_Union[_share_pb2.NumShares, _Mapping]] = ..., share_unlocks: _Optional[_Iterable[_Union[_share_pb2.ShareUnlock, _Mapping]]] = ..., equity: _Optional[bytes] = ..., withdrawable_equity: _Optional[bytes] = ...) -> None: ...

class QueryMegavaultAllOwnerSharesRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryMegavaultAllOwnerSharesResponse(_message.Message):
    __slots__ = ("owner_shares", "pagination")
    OWNER_SHARES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    owner_shares: _containers.RepeatedCompositeFieldContainer[_share_pb2.OwnerShare]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, owner_shares: _Optional[_Iterable[_Union[_share_pb2.OwnerShare, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryVaultParamsRequest(_message.Message):
    __slots__ = ("type", "number")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    type: _vault_pb2.VaultType
    number: int
    def __init__(self, type: _Optional[_Union[_vault_pb2.VaultType, str]] = ..., number: _Optional[int] = ...) -> None: ...

class QueryVaultParamsResponse(_message.Message):
    __slots__ = ("vault_id", "vault_params")
    VAULT_ID_FIELD_NUMBER: _ClassVar[int]
    VAULT_PARAMS_FIELD_NUMBER: _ClassVar[int]
    vault_id: _vault_pb2.VaultId
    vault_params: _params_pb2.VaultParams
    def __init__(self, vault_id: _Optional[_Union[_vault_pb2.VaultId, _Mapping]] = ..., vault_params: _Optional[_Union[_params_pb2.VaultParams, _Mapping]] = ...) -> None: ...

class QueryMegavaultWithdrawalInfoRequest(_message.Message):
    __slots__ = ("shares_to_withdraw",)
    SHARES_TO_WITHDRAW_FIELD_NUMBER: _ClassVar[int]
    shares_to_withdraw: _share_pb2.NumShares
    def __init__(self, shares_to_withdraw: _Optional[_Union[_share_pb2.NumShares, _Mapping]] = ...) -> None: ...

class QueryMegavaultWithdrawalInfoResponse(_message.Message):
    __slots__ = ("shares_to_withdraw", "expected_quote_quantums", "megavault_equity", "total_shares")
    SHARES_TO_WITHDRAW_FIELD_NUMBER: _ClassVar[int]
    EXPECTED_QUOTE_QUANTUMS_FIELD_NUMBER: _ClassVar[int]
    MEGAVAULT_EQUITY_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SHARES_FIELD_NUMBER: _ClassVar[int]
    shares_to_withdraw: _share_pb2.NumShares
    expected_quote_quantums: bytes
    megavault_equity: bytes
    total_shares: _share_pb2.NumShares
    def __init__(self, shares_to_withdraw: _Optional[_Union[_share_pb2.NumShares, _Mapping]] = ..., expected_quote_quantums: _Optional[bytes] = ..., megavault_equity: _Optional[bytes] = ..., total_shares: _Optional[_Union[_share_pb2.NumShares, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/store/v1beta1/listening.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cosmos/store/v1beta1/listening.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.tendermint.abci import types_pb2 as tendermint_dot_abci_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/store/v1beta1/listening.proto\x12\x14\x63osmos.store.v1beta1\x1a\x1btendermint/abci/types.proto\"L\n\x0bStoreKVPair\x12\x11\n\tstore_key\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\x08\x12\x0b\n\x03key\x18\x03 \x01(\x0c\x12\r\n\x05value\x18\x04 \x01(\x0c\"\xf7\x01\n\rBlockMetadata\x12\x38\n\x0fresponse_commit\x18\x06 \x01(\x0b\x32\x1f.tendermint.abci.ResponseCommit\x12\x45\n\x16request_finalize_block\x18\x07 \x01(\x0b\x32%.tendermint.abci.RequestFinalizeBlock\x12G\n\x17response_finalize_block\x18\x08 \x01(\x0b\x32&.tendermint.abci.ResponseFinalizeBlockJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06\x42\x1aZ\x18\x63osmossdk.io/store/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.store.v1beta1.listening_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\030cosmossdk.io/store/types'
  _globals['_STOREKVPAIR']._serialized_start=91
  _globals['_STOREKVPAIR']._serialized_end=167
  _globals['_BLOCKMETADATA']._serialized_start=170
  _globals['_BLOCKMETADATA']._serialized_end=417
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("constant_fee",)
    CONSTANT_FEE_FIELD_NUMBER: _ClassVar[int]
    constant_fee: _coin_pb2.Coin
    def __init__(self, constant_fee: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
EXPERT_CUSTOM_RENDERER_FIELD_NUMBER: _ClassVar[int]
expert_custom_renderer: _descriptor.FieldDescriptor



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/stats/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/stats/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.dydxprotocol.stats import params_pb2 as dydxprotocol_dot_stats_dot_params__pb2
from v4_proto.dydxprotocol.stats import stats_pb2 as dydxprotocol_dot_stats_dot_stats__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x64ydxprotocol/stats/query.proto\x12\x12\x64ydxprotocol.stats\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1f\x64ydxprotocol/stats/params.proto\x1a\x1e\x64ydxprotocol/stats/stats.proto\"\x14\n\x12QueryParamsRequest\"G\n\x13QueryParamsResponse\x12\x30\n\x06params\x18\x01 \x01(\x0b\x32\x1a.dydxprotocol.stats.ParamsB\x04\xc8\xde\x1f\x00\"\x1b\n\x19QueryStatsMetadataRequest\"Q\n\x1aQueryStatsMetadataResponse\x12\x33\n\x08metadata\x18\x01 \x01(\x0b\x32!.dydxprotocol.stats.StatsMetadata\"\x19\n\x17QueryGlobalStatsRequest\"J\n\x18QueryGlobalStatsResponse\x12.\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.dydxprotocol.stats.GlobalStats\"%\n\x15QueryUserStatsRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\"F\n\x16QueryUserStatsResponse\x12,\n\x05stats\x18\x01 \x01(\x0b\x32\x1d.dydxprotocol.stats.UserStats2\xd2\x04\n\x05Query\x12\x80\x01\n\x06Params\x12&.dydxprotocol.stats.QueryParamsRequest\x1a\'.dydxprotocol.stats.QueryParamsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/dydxprotocol/v4/stats/params\x12\x9d\x01\n\rStatsMetadata\x12-.dydxprotocol.stats.QueryStatsMetadataRequest\x1a..dydxprotocol.stats.QueryStatsMetadataResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/dydxprotocol/v4/stats/stats_metadata\x12\x95\x01\n\x0bGlobalStats\x12+.dydxprotocol.stats.QueryGlobalStatsRequest\x1a,.dydxprotocol.stats.QueryGlobalStatsResponse\"+\x82\xd3\xe4\x93\x02%\x12#/dydxprotocol/v4/stats/global_stats\x12\x8d\x01\n\tUserStats\x12).dydxprotocol.stats.QueryUserStatsRequest\x1a*.dydxprotocol.stats.QueryUserStatsResponse\")\x82\xd3\xe4\x93\x02#\x12!/dydxprotocol/v4/stats/user_statsB9Z7github.com/dydxprotocol/v4-chain/protocol/x/stats/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.stats.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/dydxprotocol/v4-chain/protocol/x/stats/types'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\037\022\035/dydxprotocol/v4/stats/params'
  _globals['_QUERY'].methods_by_name['StatsMetadata']._loaded_options = None
  _globals['_QUERY'].methods_by_name['StatsMetadata']._serialized_options = b'\202\323\344\223\002\'\022%/dydxprotocol/v4/stats/stats_metadata'
  _globals['_QUERY'].methods_by_name['GlobalStats']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GlobalStats']._serialized_options = b'\202\323\344\223\002%\022#/dydxprotocol/v4/stats/global_stats'
  _globals['_QUERY'].methods_by_name['UserStats']._loaded_options = None
  _globals['_QUERY'].methods_by_name['UserStats']._serialized_options = b'\202\323\344\223\002#\022!/dydxprotocol/v4/stats/user_stats'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=171
  _globals['_QUERYPARAMSREQUEST']._serialized_end=191
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=193
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=264
  _globals['_QUERYSTATSMETADATAREQUEST']._serialized_start=266
  _globals['_QUERYSTATSMETADATAREQUEST']._serialized_end=293
  _globals['_QUERYSTATSMETADATARESPONSE']._serialized_start=295
  _globals['_QUERYSTATSMETADATARESPONSE']._serialized_end=376
  _globals['_QUERYGLOBALSTATSREQUEST']._serialized_start=378
  _globals['_QUERYGLOBALSTATSREQUEST']._serialized_end=403
  _globals['_QUERYGLOBALSTATSRESPONSE']._serialized_start=405
  _globals['_QUERYGLOBALSTATSRESPONSE']._serialized_end=479
  _globals['_QUERYUSERSTATSREQUEST']._serialized_start=481
  _globals['_QUERYUSERSTATSREQUEST']._serialized_end=518
  _globals['_QUERYUSERSTATSRESPONSE']._serialized_start=520
  _globals['_QUERYUSERSTATSRESPONSE']._serialized_end=590
  _globals['_QUERY']._serialized_start=593
  _globals['_QUERY']._serialized_end=1187
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/stats/params.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/stats/params.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x64ydxprotocol/stats/params.proto\x12\x12\x64ydxprotocol.stats\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\"F\n\x06Params\x12<\n\x0fwindow_duration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\x42\x39Z7github.com/dydxprotocol/v4-chain/protocol/x/stats/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.stats.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/dydxprotocol/v4-chain/protocol/x/stats/types'
  _globals['_PARAMS'].fields_by_name['window_duration']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['window_duration']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _globals['_PARAMS']._serialized_start=109
  _globals['_PARAMS']._serialized_end=179
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
TABLE_FIELD_NUMBER: _ClassVar[int]
table: _descriptor.FieldDescriptor
SINGLETON_FIELD_NUMBER: _ClassVar[int]
singleton: _descriptor.FieldDescriptor

class TableDescriptor(_message.Message):
    __slots__ = ("primary_key", "index", "id")
    PRIMARY_KEY_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    primary_key: PrimaryKeyDescriptor
    index: _containers.RepeatedCompositeFieldContainer[SecondaryIndexDescriptor]
    id: int
    def __init__(self, primary_key: _Optional[_Union[PrimaryKeyDescriptor, _Mapping]] = ..., index: _Optional[_Iterable[_Union[SecondaryIndexDescriptor, _Mapping]]] = ..., id: _Optional[int] = ...) -> None: ...

class PrimaryKeyDescriptor(_message.Message):
    __slots__ = ("fields", "auto_increment")
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    AUTO_INCREMENT_FIELD_NUMBER: _ClassVar[int]
    fields: str
    auto_increment: bool
    def __init__(self, fields: _Optional[str] = ..., auto_increment: bool = ...) -> None: ...

class SecondaryIndexDescriptor(_message.Message):
    __slots__ = ("fields", "id", "unique")
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    UNIQUE_FIELD_NUMBER: _ClassVar[int]
    fields: str
    id: int
    unique: bool
    def __init__(self, fields: _Optional[str] = ..., id: _Optional[int] = ..., unique: bool = ...) -> None: ...

class SingletonDescriptor(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    def __init__(self, id: _Optional[int] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Permissions(_message.Message):
    __slots__ = ("level", "limit_type_urls")
    class Level(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        LEVEL_NONE_UNSPECIFIED: _ClassVar[Permissions.Level]
        LEVEL_SOME_MSGS: _ClassVar[Permissions.Level]
        LEVEL_ALL_MSGS: _ClassVar[Permissions.Level]
        LEVEL_SUPER_ADMIN: _ClassVar[Permissions.Level]
    LEVEL_NONE_UNSPECIFIED: Permissions.Level
    LEVEL_SOME_MSGS: Permissions.Level
    LEVEL_ALL_MSGS: Permissions.Level
    LEVEL_SUPER_ADMIN: Permissions.Level
    LEVEL_FIELD_NUMBER: _ClassVar[int]
    LIMIT_TYPE_URLS_FIELD_NUMBER: _ClassVar[int]
    level: Permissions.Level
    limit_type_urls: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, level: _Optional[_Union[Permissions.Level, str]] = ..., limit_type_urls: _Optional[_Iterable[str]] = ...) -> None: ...

class GenesisAccountPermissions(_message.Message):
    __slots__ = ("address", "permissions")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    address: str
    permissions: Permissions
    def __init__(self, address: _Optional[str] = ..., permissions: _Optional[_Union[Permissions, _Mapping]] = ...) -> None: ...

class GenesisState(_message.Message):
    __slots__ = ("account_permissions", "disabled_type_urls")
    ACCOUNT_PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    DISABLED_TYPE_URLS_FIELD_NUMBER: _ClassVar[int]
    account_permissions: _containers.RepeatedCompositeFieldContainer[GenesisAccountPermissions]
    disabled_type_urls: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, account_permissions: _Optional[_Iterable[_Union[GenesisAccountPermissions, _Mapping]]] = ..., disabled_type_urls: _Optional[_Iterable[str]] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as _subaccount_pb2
from v4_proto.dydxprotocol.clob import clob_pair_pb2 as _clob_pair_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MEVMatch(_message.Message):
    __slots__ = ("taker_order_subaccount_id", "taker_fee_ppm", "maker_order_subaccount_id", "maker_order_subticks", "maker_order_is_buy", "maker_fee_ppm", "clob_pair_id", "fill_amount")
    TAKER_ORDER_SUBACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    TAKER_FEE_PPM_FIELD_NUMBER: _ClassVar[int]
    MAKER_ORDER_SUBACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    MAKER_ORDER_SUBTICKS_FIELD_NUMBER: _ClassVar[int]
    MAKER_ORDER_IS_BUY_FIELD_NUMBER: _ClassVar[int]
    MAKER_FEE_PPM_FIELD_NUMBER: _ClassVar[int]
    CLOB_PAIR_ID_FIELD_NUMBER: _ClassVar[int]
    FILL_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    taker_order_subaccount_id: _subaccount_pb2.SubaccountId
    taker_fee_ppm: int
    maker_order_subaccount_id: _subaccount_pb2.SubaccountId
    maker_order_subticks: int
    maker_order_is_buy: bool
    maker_fee_ppm: int
    clob_pair_id: int
    fill_amount: int
    def __init__(self, taker_order_subaccount_id: _Optional[_Union[_subaccount_pb2.SubaccountId, _Mapping]] = ..., taker_fee_ppm: _Optional[int] = ..., maker_order_subaccount_id: _Optional[_Union[_subaccount_pb2.SubaccountId, _Mapping]] = ..., maker_order_subticks: _Optional[int] = ..., maker_order_is_buy: bool = ..., maker_fee_ppm: _Optional[int] = ..., clob_pair_id: _Optional[int] = ..., fill_amount: _Optional[int] = ...) -> None: ...

class MEVLiquidationMatch(_message.Message):
    __slots__ = ("liquidated_subaccount_id", "insurance_fund_delta_quote_quantums", "maker_order_subaccount_id", "maker_order_subticks", "maker_order_is_buy", "maker_fee_ppm", "clob_pair_id", "fill_amount")
    LIQUIDATED_SUBACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    INSURANCE_FUND_DELTA_QUOTE_QUANTUMS_FIELD_NUMBER: _ClassVar[int]
    MAKER_ORDER_SUBACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    MAKER_ORDER_SUBTICKS_FIELD_NUMBER: _ClassVar[int]
    MAKER_ORDER_IS_BUY_FIELD_NUMBER: _ClassVar[int]
    MAKER_FEE_PPM_FIELD_NUMBER: _ClassVar[int]
    CLOB_PAIR_ID_FIELD_NUMBER: _ClassVar[int]
    FILL_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    liquidated_subaccount_id: _subaccount_pb2.SubaccountId
    insurance_fund_delta_quote_quantums: int
    maker_order_subaccount_id: _subaccount_pb2.SubaccountId
    maker_order_subticks: int
    maker_order_is_buy: bool
    maker_fee_ppm: int
    clob_pair_id: int
    fill_amount: int
    def __init__(self, liquidated_subaccount_id: _Optional[_Union[_subaccount_pb2.SubaccountId, _Mapping]] = ..., insurance_fund_delta_quote_quantums: _Optional[int] = ..., maker_order_subaccount_id: _Optional[_Union[_subaccount_pb2.SubaccountId, _Mapping]] = ..., maker_order_subticks: _Optional[int] = ..., maker_order_is_buy: bool = ..., maker_fee_ppm: _Optional[int] = ..., clob_pair_id: _Optional[int] = ..., fill_amount: _Optional[int] = ...) -> None: ...

class ClobMidPrice(_message.Message):
    __slots__ = ("clob_pair", "subticks")
    CLOB_PAIR_FIELD_NUMBER: _ClassVar[int]
    SUBTICKS_FIELD_NUMBER: _ClassVar[int]
    clob_pair: _clob_pair_pb2.ClobPair
    subticks: int
    def __init__(self, clob_pair: _Optional[_Union[_clob_pair_pb2.ClobPair, _Mapping]] = ..., subticks: _Optional[int] = ...) -> None: ...

class ValidatorMevMatches(_message.Message):
    __slots__ = ("matches", "liquidation_matches")
    MATCHES_FIELD_NUMBER: _ClassVar[int]
    LIQUIDATION_MATCHES_FIELD_NUMBER: _ClassVar[int]
    matches: _containers.RepeatedCompositeFieldContainer[MEVMatch]
    liquidation_matches: _containers.RepeatedCompositeFieldContainer[MEVLiquidationMatch]
    def __init__(self, matches: _Optional[_Iterable[_Union[MEVMatch, _Mapping]]] = ..., liquidation_matches: _Optional[_Iterable[_Union[MEVLiquidationMatch, _Mapping]]] = ...) -> None: ...

class MevNodeToNodeMetrics(_message.Message):
    __slots__ = ("validator_mev_matches", "clob_mid_prices", "bp_mev_matches", "proposal_receive_time")
    VALIDATOR_MEV_MATCHES_FIELD_NUMBER: _ClassVar[int]
    CLOB_MID_PRICES_FIELD_NUMBER: _ClassVar[int]
    BP_MEV_MATCHES_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_RECEIVE_TIME_FIELD_NUMBER: _ClassVar[int]
    validator_mev_matches: ValidatorMevMatches
    clob_mid_prices: _containers.RepeatedCompositeFieldContainer[ClobMidPrice]
    bp_mev_matches: ValidatorMevMatches
    proposal_receive_time: int
    def __init__(self, validator_mev_matches: _Optional[_Union[ValidatorMevMatches, _Mapping]] = ..., clob_mid_prices: _Optional[_Iterable[_Union[ClobMidPrice, _Mapping]]] = ..., bp_mev_matches: _Optional[_Union[ValidatorMevMatches, _Mapping]] = ..., proposal_receive_time: _Optional[int] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ListingVaultDepositParams(_message.Message):
    __slots__ = ("new_vault_deposit_amount", "main_vault_deposit_amount", "num_blocks_to_lock_shares")
    NEW_VAULT_DEPOSIT_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    MAIN_VAULT_DEPOSIT_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    NUM_BLOCKS_TO_LOCK_SHARES_FIELD_NUMBER: _ClassVar[int]
    new_vault_deposit_amount: bytes
    main_vault_deposit_amount: bytes
    num_blocks_to_lock_shares: int
    def __init__(self, new_vault_deposit_amount: _Optional[bytes] = ..., main_vault_deposit_amount: _Optional[bytes] = ..., num_blocks_to_lock_shares: _Optional[int] = ...) -> None: ...



from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.affiliates import affiliates_pb2 as _affiliates_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AffiliateInfoRequest(_message.Message):
    __slots__ = ("address",)
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: str
    def __init__(self, address: _Optional[str] = ...) -> None: ...

class AffiliateInfoResponse(_message.Message):
    __slots__ = ("is_whitelisted", "tier", "fee_share_ppm", "referred_volume", "staked_amount")
    IS_WHITELISTED_FIELD_NUMBER: _ClassVar[int]
    TIER_FIELD_NUMBER: _ClassVar[int]
    FEE_SHARE_PPM_FIELD_NUMBER: _ClassVar[int]
    REFERRED_VOLUME_FIELD_NUMBER: _ClassVar[int]
    STAKED_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    is_whitelisted: bool
    tier: int
    fee_share_ppm: int
    referred_volume: bytes
    staked_amount: bytes
    def __init__(self, is_whitelisted: bool = ..., tier: _Optional[int] = ..., fee_share_ppm: _Optional[int] = ..., referred_volume: _Optional[bytes] = ..., staked_amount: _Optional[bytes] = ...) -> None: ...

class ReferredByRequest(_message.Message):
    __slots__ = ("address",)
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: str
    def __init__(self, address: _Optional[str] = ...) -> None: ...

class ReferredByResponse(_message.Message):
    __slots__ = ("affiliate_address",)
    AFFILIATE_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    affiliate_address: str
    def __init__(self, affiliate_address: _Optional[str] = ...) -> None: ...

class AllAffiliateTiersRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class AllAffiliateTiersResponse(_message.Message):
    __slots__ = ("tiers",)
    TIERS_FIELD_NUMBER: _ClassVar[int]
    tiers: _affiliates_pb2.AffiliateTiers
    def __init__(self, tiers: _Optional[_Union[_affiliates_pb2.AffiliateTiers, _Mapping]] = ...) -> None: ...

class AffiliateWhitelistRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class AffiliateWhitelistResponse(_message.Message):
    __slots__ = ("whitelist",)
    WHITELIST_FIELD_NUMBER: _ClassVar[int]
    whitelist: _affiliates_pb2.AffiliateWhitelist
    def __init__(self, whitelist: _Optional[_Union[_affiliates_pb2.AffiliateWhitelist, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class StorageType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    STORAGE_TYPE_DEFAULT_UNSPECIFIED: _ClassVar[StorageType]
    STORAGE_TYPE_MEMORY: _ClassVar[StorageType]
    STORAGE_TYPE_TRANSIENT: _ClassVar[StorageType]
STORAGE_TYPE_DEFAULT_UNSPECIFIED: StorageType
STORAGE_TYPE_MEMORY: StorageType
STORAGE_TYPE_TRANSIENT: StorageType
MODULE_SCHEMA_FIELD_NUMBER: _ClassVar[int]
module_schema: _descriptor.FieldDescriptor

class ModuleSchemaDescriptor(_message.Message):
    __slots__ = ("schema_file", "prefix")
    class FileEntry(_message.Message):
        __slots__ = ("id", "proto_file_name", "storage_type")
        ID_FIELD_NUMBER: _ClassVar[int]
        PROTO_FILE_NAME_FIELD_NUMBER: _ClassVar[int]
        STORAGE_TYPE_FIELD_NUMBER: _ClassVar[int]
        id: int
        proto_file_name: str
        storage_type: StorageType
        def __init__(self, id: _Optional[int] = ..., proto_file_name: _Optional[str] = ..., storage_type: _Optional[_Union[StorageType, str]] = ...) -> None: ...
    SCHEMA_FILE_FIELD_NUMBER: _ClassVar[int]
    PREFIX_FIELD_NUMBER: _ClassVar[int]
    schema_file: _containers.RepeatedCompositeFieldContainer[ModuleSchemaDescriptor.FileEntry]
    prefix: bytes
    def __init__(self, schema_file: _Optional[_Iterable[_Union[ModuleSchemaDescriptor.FileEntry, _Mapping]]] = ..., prefix: _Optional[bytes] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/crypto/secp256k1/keys.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cosmos/crypto/secp256k1/keys.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"cosmos/crypto/secp256k1/keys.proto\x12\x17\x63osmos.crypto.secp256k1\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\"H\n\x06PubKey\x12\x0b\n\x03key\x18\x01 \x01(\x0c:1\x98\xa0\x1f\x00\x8a\xe7\xb0*\x1atendermint/PubKeySecp256k1\x92\xe7\xb0*\tkey_field\"F\n\x07PrivKey\x12\x0b\n\x03key\x18\x01 \x01(\x0c:.\x8a\xe7\xb0*\x1btendermint/PrivKeySecp256k1\x92\xe7\xb0*\tkey_fieldB4Z2github.com/cosmos/cosmos-sdk/crypto/keys/secp256k1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crypto.secp256k1.keys_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z2github.com/cosmos/cosmos-sdk/crypto/keys/secp256k1'
  _globals['_PUBKEY']._loaded_options = None
  _globals['_PUBKEY']._serialized_options = b'\230\240\037\000\212\347\260*\032tendermint/PubKeySecp256k1\222\347\260*\tkey_field'
  _globals['_PRIVKEY']._loaded_options = None
  _globals['_PRIVKEY']._serialized_options = b'\212\347\260*\033tendermint/PrivKeySecp256k1\222\347\260*\tkey_field'
  _globals['_PUBKEY']._serialized_start=104
  _globals['_PUBKEY']._serialized_end=176
  _globals['_PRIVKEY']._serialized_start=178
  _globals['_PRIVKEY']._serialized_end=248
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tendermint/crypto/keys.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'tendermint/crypto/keys.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ctendermint/crypto/keys.proto\x12\x11tendermint.crypto\x1a\x14gogoproto/gogo.proto\"D\n\tPublicKey\x12\x11\n\x07\x65\x64\x32\x35\x35\x31\x39\x18\x01 \x01(\x0cH\x00\x12\x13\n\tsecp256k1\x18\x02 \x01(\x0cH\x00:\x08\xe8\xa0\x1f\x01\xe8\xa1\x1f\x01\x42\x05\n\x03sumB6Z4github.com/cometbft/cometbft/proto/tendermint/cryptob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.crypto.keys_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z4github.com/cometbft/cometbft/proto/tendermint/crypto'
  _globals['_PUBLICKEY']._loaded_options = None
  _globals['_PUBLICKEY']._serialized_options = b'\350\240\037\001\350\241\037\001'
  _globals['_PUBLICKEY']._serialized_start=73
  _globals['_PUBLICKEY']._serialized_end=141
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/clob/finalize_block.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/clob/finalize_block.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.dydxprotocol.clob import clob_pair_pb2 as dydxprotocol_dot_clob_dot_clob__pair__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&dydxprotocol/clob/finalize_block.proto\x12\x11\x64ydxprotocol.clob\x1a!dydxprotocol/clob/clob_pair.proto\"`\n\x1c\x43lobStagedFinalizeBlockEvent\x12\x37\n\x10\x63reate_clob_pair\x18\x01 \x01(\x0b\x32\x1b.dydxprotocol.clob.ClobPairH\x00\x42\x07\n\x05\x65ventB8Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.clob.finalize_block_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/types'
  _globals['_CLOBSTAGEDFINALIZEBLOCKEVENT']._serialized_start=96
  _globals['_CLOBSTAGEDFINALIZEBLOCKEVENT']._serialized_end=192
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from v4_proto.dydxprotocol.perpetuals import params_pb2 as _params_pb2
from v4_proto.dydxprotocol.perpetuals import perpetual_pb2 as _perpetual_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryPerpetualRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    def __init__(self, id: _Optional[int] = ...) -> None: ...

class QueryPerpetualResponse(_message.Message):
    __slots__ = ("perpetual",)
    PERPETUAL_FIELD_NUMBER: _ClassVar[int]
    perpetual: _perpetual_pb2.Perpetual
    def __init__(self, perpetual: _Optional[_Union[_perpetual_pb2.Perpetual, _Mapping]] = ...) -> None: ...

class QueryAllPerpetualsRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryAllPerpetualsResponse(_message.Message):
    __slots__ = ("perpetual", "pagination")
    PERPETUAL_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    perpetual: _containers.RepeatedCompositeFieldContainer[_perpetual_pb2.Perpetual]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, perpetual: _Optional[_Iterable[_Union[_perpetual_pb2.Perpetual, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryAllLiquidityTiersRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryAllLiquidityTiersResponse(_message.Message):
    __slots__ = ("liquidity_tiers", "pagination")
    LIQUIDITY_TIERS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    liquidity_tiers: _containers.RepeatedCompositeFieldContainer[_perpetual_pb2.LiquidityTier]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, liquidity_tiers: _Optional[_Iterable[_Union[_perpetual_pb2.LiquidityTier, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryPremiumVotesRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryPremiumVotesResponse(_message.Message):
    __slots__ = ("premium_votes",)
    PREMIUM_VOTES_FIELD_NUMBER: _ClassVar[int]
    premium_votes: _perpetual_pb2.PremiumStore
    def __init__(self, premium_votes: _Optional[_Union[_perpetual_pb2.PremiumStore, _Mapping]] = ...) -> None: ...

class QueryPremiumSamplesRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryPremiumSamplesResponse(_message.Message):
    __slots__ = ("premium_samples",)
    PREMIUM_SAMPLES_FIELD_NUMBER: _ClassVar[int]
    premium_samples: _perpetual_pb2.PremiumStore
    def __init__(self, premium_samples: _Optional[_Union[_perpetual_pb2.PremiumStore, _Mapping]] = ...) -> None: ...

class QueryParamsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryParamsResponse(_message.Message):
    __slots__ = ("params",)
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.Params
    def __init__(self, params: _Optional[_Union[_params_pb2.Params, _Mapping]] = ...) -> None: ...

class QueryNextPerpetualIdRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryNextPerpetualIdResponse(_message.Message):
    __slots__ = ("next_perpetual_id",)
    NEXT_PERPETUAL_ID_FIELD_NUMBER: _ClassVar[int]
    next_perpetual_id: int
    def __init__(self, next_perpetual_id: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/prices/market_param.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/prices/market_param.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&dydxprotocol/prices/market_param.proto\x12\x13\x64ydxprotocol.prices\"\x90\x01\n\x0bMarketParam\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04pair\x18\x02 \x01(\t\x12\x14\n\x08\x65xponent\x18\x03 \x01(\x11\x42\x02\x18\x01\x12\x15\n\rmin_exchanges\x18\x04 \x01(\r\x12\x1c\n\x14min_price_change_ppm\x18\x05 \x01(\r\x12\x1c\n\x14\x65xchange_config_json\x18\x06 \x01(\tB:Z8github.com/dydxprotocol/v4-chain/protocol/x/prices/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.prices.market_param_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z8github.com/dydxprotocol/v4-chain/protocol/x/prices/types'
  _globals['_MARKETPARAM'].fields_by_name['exponent']._loaded_options = None
  _globals['_MARKETPARAM'].fields_by_name['exponent']._serialized_options = b'\030\001'
  _globals['_MARKETPARAM']._serialized_start=64
  _globals['_MARKETPARAM']._serialized_end=208
# @@protoc_insertion_point(module_scope)



import datetime

from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LimitParams(_message.Message):
    __slots__ = ("denom", "limiters")
    DENOM_FIELD_NUMBER: _ClassVar[int]
    LIMITERS_FIELD_NUMBER: _ClassVar[int]
    denom: str
    limiters: _containers.RepeatedCompositeFieldContainer[Limiter]
    def __init__(self, denom: _Optional[str] = ..., limiters: _Optional[_Iterable[_Union[Limiter, _Mapping]]] = ...) -> None: ...

class Limiter(_message.Message):
    __slots__ = ("period", "baseline_minimum", "baseline_tvl_ppm")
    PERIOD_FIELD_NUMBER: _ClassVar[int]
    BASELINE_MINIMUM_FIELD_NUMBER: _ClassVar[int]
    BASELINE_TVL_PPM_FIELD_NUMBER: _ClassVar[int]
    period: _duration_pb2.Duration
    baseline_minimum: bytes
    baseline_tvl_ppm: int
    def __init__(self, period: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., baseline_minimum: _Optional[bytes] = ..., baseline_tvl_ppm: _Optional[int] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from v4_proto.dydxprotocol.epochs import epoch_info_pb2 as _epoch_info_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryGetEpochInfoRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class QueryEpochInfoResponse(_message.Message):
    __slots__ = ("epoch_info",)
    EPOCH_INFO_FIELD_NUMBER: _ClassVar[int]
    epoch_info: _epoch_info_pb2.EpochInfo
    def __init__(self, epoch_info: _Optional[_Union[_epoch_info_pb2.EpochInfo, _Mapping]] = ...) -> None: ...

class QueryAllEpochInfoRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryEpochInfoAllResponse(_message.Message):
    __slots__ = ("epoch_info", "pagination")
    EPOCH_INFO_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    epoch_info: _containers.RepeatedCompositeFieldContainer[_epoch_info_pb2.EpochInfo]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, epoch_info: _Optional[_Iterable[_Union[_epoch_info_pb2.EpochInfo, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/feegrant/v1beta1/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cosmos/feegrant/v1beta1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos.feegrant.v1beta1 import feegrant_pb2 as cosmos_dot_feegrant_dot_v1beta1_dot_feegrant__pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cosmos/feegrant/v1beta1/query.proto\x12\x17\x63osmos.feegrant.v1beta1\x1a&cosmos/feegrant/v1beta1/feegrant.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19\x63osmos_proto/cosmos.proto\"m\n\x15QueryAllowanceRequest\x12)\n\x07granter\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12)\n\x07grantee\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"K\n\x16QueryAllowanceResponse\x12\x31\n\tallowance\x18\x01 \x01(\x0b\x32\x1e.cosmos.feegrant.v1beta1.Grant\"\x7f\n\x16QueryAllowancesRequest\x12)\n\x07grantee\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x8a\x01\n\x17QueryAllowancesResponse\x12\x32\n\nallowances\x18\x01 \x03(\x0b\x32\x1e.cosmos.feegrant.v1beta1.Grant\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x88\x01\n\x1fQueryAllowancesByGranterRequest\x12)\n\x07granter\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x93\x01\n QueryAllowancesByGranterResponse\x12\x32\n\nallowances\x18\x01 \x03(\x0b\x32\x1e.cosmos.feegrant.v1beta1.Grant\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\x9f\x04\n\x05Query\x12\xac\x01\n\tAllowance\x12..cosmos.feegrant.v1beta1.QueryAllowanceRequest\x1a/.cosmos.feegrant.v1beta1.QueryAllowanceResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/cosmos/feegrant/v1beta1/allowance/{granter}/{grantee}\x12\xa6\x01\n\nAllowances\x12/.cosmos.feegrant.v1beta1.QueryAllowancesRequest\x1a\x30.cosmos.feegrant.v1beta1.QueryAllowancesResponse\"5\x82\xd3\xe4\x93\x02/\x12-/cosmos/feegrant/v1beta1/allowances/{grantee}\x12\xbd\x01\n\x13\x41llowancesByGranter\x12\x38.cosmos.feegrant.v1beta1.QueryAllowancesByGranterRequest\x1a\x39.cosmos.feegrant.v1beta1.QueryAllowancesByGranterResponse\"1\x82\xd3\xe4\x93\x02+\x12)/cosmos/feegrant/v1beta1/issued/{granter}B\x19Z\x17\x63osmossdk.io/x/feegrantb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.feegrant.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\027cosmossdk.io/x/feegrant'
  _globals['_QUERYALLOWANCEREQUEST'].fields_by_name['granter']._loaded_options = None
  _globals['_QUERYALLOWANCEREQUEST'].fields_by_name['granter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYALLOWANCEREQUEST'].fields_by_name['grantee']._loaded_options = None
  _globals['_QUERYALLOWANCEREQUEST'].fields_by_name['grantee']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYALLOWANCESREQUEST'].fields_by_name['grantee']._loaded_options = None
  _globals['_QUERYALLOWANCESREQUEST'].fields_by_name['grantee']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYALLOWANCESBYGRANTERREQUEST'].fields_by_name['granter']._loaded_options = None
  _globals['_QUERYALLOWANCESBYGRANTERREQUEST'].fields_by_name['granter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERY'].methods_by_name['Allowance']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Allowance']._serialized_options = b'\202\323\344\223\0028\0226/cosmos/feegrant/v1beta1/allowance/{granter}/{grantee}'
  _globals['_QUERY'].methods_by_name['Allowances']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Allowances']._serialized_options = b'\202\323\344\223\002/\022-/cosmos/feegrant/v1beta1/allowances/{grantee}'
  _globals['_QUERY'].methods_by_name['AllowancesByGranter']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AllowancesByGranter']._serialized_options = b'\202\323\344\223\002+\022)/cosmos/feegrant/v1beta1/issued/{granter}'
  _globals['_QUERYALLOWANCEREQUEST']._serialized_start=205
  _globals['_QUERYALLOWANCEREQUEST']._serialized_end=314
  _globals['_QUERYALLOWANCERESPONSE']._serialized_start=316
  _globals['_QUERYALLOWANCERESPONSE']._serialized_end=391
  _globals['_QUERYALLOWANCESREQUEST']._serialized_start=393
  _globals['_QUERYALLOWANCESREQUEST']._serialized_end=520
  _globals['_QUERYALLOWANCESRESPONSE']._serialized_start=523
  _globals['_QUERYALLOWANCESRESPONSE']._serialized_end=661
  _globals['_QUERYALLOWANCESBYGRANTERREQUEST']._serialized_start=664
  _globals['_QUERYALLOWANCESBYGRANTERREQUEST']._serialized_end=800
  _globals['_QUERYALLOWANCESBYGRANTERRESPONSE']._serialized_start=803
  _globals['_QUERYALLOWANCESBYGRANTERRESPONSE']._serialized_end=950
  _globals['_QUERY']._serialized_start=953
  _globals['_QUERY']._serialized_end=1496
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NetAddress(_message.Message):
    __slots__ = ("id", "ip", "port")
    ID_FIELD_NUMBER: _ClassVar[int]
    IP_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    id: str
    ip: str
    port: int
    def __init__(self, id: _Optional[str] = ..., ip: _Optional[str] = ..., port: _Optional[int] = ...) -> None: ...

class ProtocolVersion(_message.Message):
    __slots__ = ("p2p", "block", "app")
    P2P_FIELD_NUMBER: _ClassVar[int]
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    APP_FIELD_NUMBER: _ClassVar[int]
    p2p: int
    block: int
    app: int
    def __init__(self, p2p: _Optional[int] = ..., block: _Optional[int] = ..., app: _Optional[int] = ...) -> None: ...

class DefaultNodeInfo(_message.Message):
    __slots__ = ("protocol_version", "default_node_id", "listen_addr", "network", "version", "channels", "moniker", "other")
    PROTOCOL_VERSION_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_NODE_ID_FIELD_NUMBER: _ClassVar[int]
    LISTEN_ADDR_FIELD_NUMBER: _ClassVar[int]
    NETWORK_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    CHANNELS_FIELD_NUMBER: _ClassVar[int]
    MONIKER_FIELD_NUMBER: _ClassVar[int]
    OTHER_FIELD_NUMBER: _ClassVar[int]
    protocol_version: ProtocolVersion
    default_node_id: str
    listen_addr: str
    network: str
    version: str
    channels: bytes
    moniker: str
    other: DefaultNodeInfoOther
    def __init__(self, protocol_version: _Optional[_Union[ProtocolVersion, _Mapping]] = ..., default_node_id: _Optional[str] = ..., listen_addr: _Optional[str] = ..., network: _Optional[str] = ..., version: _Optional[str] = ..., channels: _Optional[bytes] = ..., moniker: _Optional[str] = ..., other: _Optional[_Union[DefaultNodeInfoOther, _Mapping]] = ...) -> None: ...

class DefaultNodeInfoOther(_message.Message):
    __slots__ = ("tx_index", "rpc_address")
    TX_INDEX_FIELD_NUMBER: _ClassVar[int]
    RPC_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    tx_index: str
    rpc_address: str
    def __init__(self, tx_index: _Optional[str] = ..., rpc_address: _Optional[str] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.dydxprotocol.bridge import bridge_event_info_pb2 as _bridge_event_info_pb2
from v4_proto.dydxprotocol.bridge import params_pb2 as _params_pb2
from v4_proto.dydxprotocol.bridge import tx_pb2 as _tx_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryEventParamsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryEventParamsResponse(_message.Message):
    __slots__ = ("params",)
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.EventParams
    def __init__(self, params: _Optional[_Union[_params_pb2.EventParams, _Mapping]] = ...) -> None: ...

class QueryProposeParamsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryProposeParamsResponse(_message.Message):
    __slots__ = ("params",)
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.ProposeParams
    def __init__(self, params: _Optional[_Union[_params_pb2.ProposeParams, _Mapping]] = ...) -> None: ...

class QuerySafetyParamsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QuerySafetyParamsResponse(_message.Message):
    __slots__ = ("params",)
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.SafetyParams
    def __init__(self, params: _Optional[_Union[_params_pb2.SafetyParams, _Mapping]] = ...) -> None: ...

class QueryAcknowledgedEventInfoRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryAcknowledgedEventInfoResponse(_message.Message):
    __slots__ = ("info",)
    INFO_FIELD_NUMBER: _ClassVar[int]
    info: _bridge_event_info_pb2.BridgeEventInfo
    def __init__(self, info: _Optional[_Union[_bridge_event_info_pb2.BridgeEventInfo, _Mapping]] = ...) -> None: ...

class QueryRecognizedEventInfoRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryRecognizedEventInfoResponse(_message.Message):
    __slots__ = ("info",)
    INFO_FIELD_NUMBER: _ClassVar[int]
    info: _bridge_event_info_pb2.BridgeEventInfo
    def __init__(self, info: _Optional[_Union[_bridge_event_info_pb2.BridgeEventInfo, _Mapping]] = ...) -> None: ...

class QueryDelayedCompleteBridgeMessagesRequest(_message.Message):
    __slots__ = ("address",)
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: str
    def __init__(self, address: _Optional[str] = ...) -> None: ...

class QueryDelayedCompleteBridgeMessagesResponse(_message.Message):
    __slots__ = ("messages",)
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    messages: _containers.RepeatedCompositeFieldContainer[DelayedCompleteBridgeMessage]
    def __init__(self, messages: _Optional[_Iterable[_Union[DelayedCompleteBridgeMessage, _Mapping]]] = ...) -> None: ...

class DelayedCompleteBridgeMessage(_message.Message):
    __slots__ = ("message", "block_height")
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    BLOCK_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    message: _tx_pb2.MsgCompleteBridge
    block_height: int
    def __init__(self, message: _Optional[_Union[_tx_pb2.MsgCompleteBridge, _Mapping]] = ..., block_height: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/vault/params.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/vault/params.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.dydxprotocol.vault import vault_pb2 as dydxprotocol_dot_vault_dot_vault__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x64ydxprotocol/vault/params.proto\x12\x12\x64ydxprotocol.vault\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x64ydxprotocol/vault/vault.proto\x1a\x14gogoproto/gogo.proto\"\xa0\x02\n\rQuotingParams\x12\x0e\n\x06layers\x18\x01 \x01(\r\x12\x16\n\x0espread_min_ppm\x18\x02 \x01(\r\x12\x19\n\x11spread_buffer_ppm\x18\x03 \x01(\r\x12\x17\n\x0fskew_factor_ppm\x18\x04 \x01(\r\x12\x1a\n\x12order_size_pct_ppm\x18\x05 \x01(\r\x12 \n\x18order_expiration_seconds\x18\x06 \x01(\r\x12u\n#activation_threshold_quote_quantums\x18\x07 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\"y\n\x0bVaultParams\x12/\n\x06status\x18\x01 \x01(\x0e\x32\x1f.dydxprotocol.vault.VaultStatus\x12\x39\n\x0equoting_params\x18\x02 \x01(\x0b\x32!.dydxprotocol.vault.QuotingParams\"z\n\x0eOperatorParams\x12*\n\x08operator\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12<\n\x08metadata\x18\x02 \x01(\x0b\x32$.dydxprotocol.vault.OperatorMetadataB\x04\xc8\xde\x1f\x00\"5\n\x10OperatorMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\x99\x02\n\x06Params\x12\x0e\n\x06layers\x18\x01 \x01(\r\x12\x16\n\x0espread_min_ppm\x18\x02 \x01(\r\x12\x19\n\x11spread_buffer_ppm\x18\x03 \x01(\r\x12\x17\n\x0fskew_factor_ppm\x18\x04 \x01(\r\x12\x1a\n\x12order_size_pct_ppm\x18\x05 \x01(\r\x12 \n\x18order_expiration_seconds\x18\x06 \x01(\r\x12u\n#activation_threshold_quote_quantums\x18\x07 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableIntB9Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.vault.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/types'
  _globals['_QUOTINGPARAMS'].fields_by_name['activation_threshold_quote_quantums']._loaded_options = None
  _globals['_QUOTINGPARAMS'].fields_by_name['activation_threshold_quote_quantums']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_OPERATORPARAMS'].fields_by_name['operator']._loaded_options = None
  _globals['_OPERATORPARAMS'].fields_by_name['operator']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_OPERATORPARAMS'].fields_by_name['metadata']._loaded_options = None
  _globals['_OPERATORPARAMS'].fields_by_name['metadata']._serialized_options = b'\310\336\037\000'
  _globals['_PARAMS'].fields_by_name['activation_threshold_quote_quantums']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['activation_threshold_quote_quantums']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_QUOTINGPARAMS']._serialized_start=137
  _globals['_QUOTINGPARAMS']._serialized_end=425
  _globals['_VAULTPARAMS']._serialized_start=427
  _globals['_VAULTPARAMS']._serialized_end=548
  _globals['_OPERATORPARAMS']._serialized_start=550
  _globals['_OPERATORPARAMS']._serialized_end=672
  _globals['_OPERATORMETADATA']._serialized_start=674
  _globals['_OPERATORMETADATA']._serialized_end=727
  _globals['_PARAMS']._serialized_start=730
  _globals['_PARAMS']._serialized_end=1011
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/crypto/hd/v1/hd.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cosmos/crypto/hd/v1/hd.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63osmos/crypto/hd/v1/hd.proto\x12\x13\x63osmos.crypto.hd.v1\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\"\x8e\x01\n\x0b\x42IP44Params\x12\x0f\n\x07purpose\x18\x01 \x01(\r\x12\x11\n\tcoin_type\x18\x02 \x01(\r\x12\x0f\n\x07\x61\x63\x63ount\x18\x03 \x01(\r\x12\x0e\n\x06\x63hange\x18\x04 \x01(\x08\x12\x15\n\raddress_index\x18\x05 \x01(\r:#\x98\xa0\x1f\x00\x8a\xe7\xb0*\x1a\x63rypto/keys/hd/BIP44ParamsB,Z&github.com/cosmos/cosmos-sdk/crypto/hd\xc8\xe1\x1e\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crypto.hd.v1.hd_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z&github.com/cosmos/cosmos-sdk/crypto/hd\310\341\036\000'
  _globals['_BIP44PARAMS']._loaded_options = None
  _globals['_BIP44PARAMS']._serialized_options = b'\230\240\037\000\212\347\260*\032crypto/keys/hd/BIP44Params'
  _globals['_BIP44PARAMS']._serialized_start=95
  _globals['_BIP44PARAMS']._serialized_end=237
# @@protoc_insertion_point(module_scope)



from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as _msg_pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as _subaccount_pb2
from v4_proto.dydxprotocol.vault import params_pb2 as _params_pb2
from v4_proto.dydxprotocol.vault import share_pb2 as _share_pb2
from v4_proto.dydxprotocol.vault import vault_pb2 as _vault_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgDepositToMegavault(_message.Message):
    __slots__ = ("subaccount_id", "quote_quantums")
    SUBACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    QUOTE_QUANTUMS_FIELD_NUMBER: _ClassVar[int]
    subaccount_id: _subaccount_pb2.SubaccountId
    quote_quantums: bytes
    def __init__(self, subaccount_id: _Optional[_Union[_subaccount_pb2.SubaccountId, _Mapping]] = ..., quote_quantums: _Optional[bytes] = ...) -> None: ...

class MsgDepositToMegavaultResponse(_message.Message):
    __slots__ = ("minted_shares",)
    MINTED_SHARES_FIELD_NUMBER: _ClassVar[int]
    minted_shares: _share_pb2.NumShares
    def __init__(self, minted_shares: _Optional[_Union[_share_pb2.NumShares, _Mapping]] = ...) -> None: ...

class MsgWithdrawFromMegavault(_message.Message):
    __slots__ = ("subaccount_id", "shares", "min_quote_quantums")
    SUBACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    SHARES_FIELD_NUMBER: _ClassVar[int]
    MIN_QUOTE_QUANTUMS_FIELD_NUMBER: _ClassVar[int]
    subaccount_id: _subaccount_pb2.SubaccountId
    shares: _share_pb2.NumShares
    min_quote_quantums: bytes
    def __init__(self, subaccount_id: _Optional[_Union[_subaccount_pb2.SubaccountId, _Mapping]] = ..., shares: _Optional[_Union[_share_pb2.NumShares, _Mapping]] = ..., min_quote_quantums: _Optional[bytes] = ...) -> None: ...

class MsgWithdrawFromMegavaultResponse(_message.Message):
    __slots__ = ("quote_quantums",)
    QUOTE_QUANTUMS_FIELD_NUMBER: _ClassVar[int]
    quote_quantums: bytes
    def __init__(self, quote_quantums: _Optional[bytes] = ...) -> None: ...

class MsgUpdateDefaultQuotingParams(_message.Message):
    __slots__ = ("authority", "default_quoting_params")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_QUOTING_PARAMS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    default_quoting_params: _params_pb2.QuotingParams
    def __init__(self, authority: _Optional[str] = ..., default_quoting_params: _Optional[_Union[_params_pb2.QuotingParams, _Mapping]] = ...) -> None: ...

class MsgUpdateDefaultQuotingParamsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgSetVaultParams(_message.Message):
    __slots__ = ("authority", "vault_id", "vault_params")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    VAULT_ID_FIELD_NUMBER: _ClassVar[int]
    VAULT_PARAMS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    vault_id: _vault_pb2.VaultId
    vault_params: _params_pb2.VaultParams
    def __init__(self, authority: _Optional[str] = ..., vault_id: _Optional[_Union[_vault_pb2.VaultId, _Mapping]] = ..., vault_params: _Optional[_Union[_params_pb2.VaultParams, _Mapping]] = ...) -> None: ...

class MsgSetVaultParamsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgUnlockShares(_message.Message):
    __slots__ = ("authority", "owner_address")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    OWNER_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    owner_address: str
    def __init__(self, authority: _Optional[str] = ..., owner_address: _Optional[str] = ...) -> None: ...

class MsgUnlockSharesResponse(_message.Message):
    __slots__ = ("unlocked_shares",)
    UNLOCKED_SHARES_FIELD_NUMBER: _ClassVar[int]
    unlocked_shares: _share_pb2.NumShares
    def __init__(self, unlocked_shares: _Optional[_Union[_share_pb2.NumShares, _Mapping]] = ...) -> None: ...

class MsgUpdateOperatorParams(_message.Message):
    __slots__ = ("authority", "params")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    params: _params_pb2.OperatorParams
    def __init__(self, authority: _Optional[str] = ..., params: _Optional[_Union[_params_pb2.OperatorParams, _Mapping]] = ...) -> None: ...

class MsgUpdateOperatorParamsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgAllocateToVault(_message.Message):
    __slots__ = ("authority", "vault_id", "quote_quantums")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    VAULT_ID_FIELD_NUMBER: _ClassVar[int]
    QUOTE_QUANTUMS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    vault_id: _vault_pb2.VaultId
    quote_quantums: bytes
    def __init__(self, authority: _Optional[str] = ..., vault_id: _Optional[_Union[_vault_pb2.VaultId, _Mapping]] = ..., quote_quantums: _Optional[bytes] = ...) -> None: ...

class MsgAllocateToVaultResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgRetrieveFromVault(_message.Message):
    __slots__ = ("authority", "vault_id", "quote_quantums")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    VAULT_ID_FIELD_NUMBER: _ClassVar[int]
    QUOTE_QUANTUMS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    vault_id: _vault_pb2.VaultId
    quote_quantums: bytes
    def __init__(self, authority: _Optional[str] = ..., vault_id: _Optional[_Union[_vault_pb2.VaultId, _Mapping]] = ..., quote_quantums: _Optional[bytes] = ...) -> None: ...

class MsgRetrieveFromVaultResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgUpdateParams(_message.Message):
    __slots__ = ("authority", "params")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    params: _params_pb2.Params
    def __init__(self, authority: _Optional[str] = ..., params: _Optional[_Union[_params_pb2.Params, _Mapping]] = ...) -> None: ...

class MsgSetVaultQuotingParams(_message.Message):
    __slots__ = ("authority", "vault_id", "quoting_params")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    VAULT_ID_FIELD_NUMBER: _ClassVar[int]
    QUOTING_PARAMS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    vault_id: _vault_pb2.VaultId
    quoting_params: _params_pb2.QuotingParams
    def __init__(self, authority: _Optional[str] = ..., vault_id: _Optional[_Union[_vault_pb2.VaultId, _Mapping]] = ..., quoting_params: _Optional[_Union[_params_pb2.QuotingParams, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/gov/v1beta1/tx.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cosmos/gov/v1beta1/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from v4_proto.cosmos.gov.v1beta1 import gov_pb2 as cosmos_dot_gov_dot_v1beta1_dot_gov__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x63osmos/gov/v1beta1/tx.proto\x12\x12\x63osmos.gov.v1beta1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1c\x63osmos/gov/v1beta1/gov.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\"\xba\x02\n\x11MsgSubmitProposal\x12\x45\n\x07\x63ontent\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\x1e\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x12z\n\x0finitial_deposit\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01\x12*\n\x08proposer\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString:6\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x08proposer\x8a\xe7\xb0*\x1c\x63osmos-sdk/MsgSubmitProposal\"F\n\x19MsgSubmitProposalResponse\x12)\n\x0bproposal_id\x18\x01 \x01(\x04\x42\x14\xea\xde\x1f\x0bproposal_id\xa8\xe7\xb0*\x01\"\xa2\x01\n\x07MsgVote\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12\'\n\x05voter\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12.\n\x06option\x18\x03 \x01(\x0e\x32\x1e.cosmos.gov.v1beta1.VoteOption:)\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x05voter\x8a\xe7\xb0*\x12\x63osmos-sdk/MsgVote\"\x11\n\x0fMsgVoteResponse\"\xdc\x01\n\x0fMsgVoteWeighted\x12)\n\x0bproposal_id\x18\x01 \x01(\x04\x42\x14\xea\xde\x1f\x0bproposal_id\xa8\xe7\xb0*\x01\x12\'\n\x05voter\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x42\n\x07options\x18\x03 \x03(\x0b\x32&.cosmos.gov.v1beta1.WeightedVoteOptionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:1\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x05voter\x8a\xe7\xb0*\x1a\x63osmos-sdk/MsgVoteWeighted\"\x19\n\x17MsgVoteWeightedResponse\"\x8d\x02\n\nMsgDeposit\x12)\n\x0bproposal_id\x18\x01 \x01(\x04\x42\x14\xea\xde\x1f\x0bproposal_id\xa8\xe7\xb0*\x01\x12+\n\tdepositor\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12q\n\x06\x61mount\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01:4\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x80\xdc \x00\x82\xe7\xb0*\tdepositor\x8a\xe7\xb0*\x15\x63osmos-sdk/MsgDeposit\"\x14\n\x12MsgDepositResponse2\xf3\x02\n\x03Msg\x12\x66\n\x0eSubmitProposal\x12%.cosmos.gov.v1beta1.MsgSubmitProposal\x1a-.cosmos.gov.v1beta1.MsgSubmitProposalResponse\x12H\n\x04Vote\x12\x1b.cosmos.gov.v1beta1.MsgVote\x1a#.cosmos.gov.v1beta1.MsgVoteResponse\x12`\n\x0cVoteWeighted\x12#.cosmos.gov.v1beta1.MsgVoteWeighted\x1a+.cosmos.gov.v1beta1.MsgVoteWeightedResponse\x12Q\n\x07\x44\x65posit\x12\x1e.cosmos.gov.v1beta1.MsgDeposit\x1a&.cosmos.gov.v1beta1.MsgDepositResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x32Z0github.com/cosmos/cosmos-sdk/x/gov/types/v1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.gov.v1beta1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0github.com/cosmos/cosmos-sdk/x/gov/types/v1beta1'
  _globals['_MSGSUBMITPROPOSAL'].fields_by_name['content']._loaded_options = None
  _globals['_MSGSUBMITPROPOSAL'].fields_by_name['content']._serialized_options = b'\312\264-\032cosmos.gov.v1beta1.Content'
  _globals['_MSGSUBMITPROPOSAL'].fields_by_name['initial_deposit']._loaded_options = None
  _globals['_MSGSUBMITPROPOSAL'].fields_by_name['initial_deposit']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_MSGSUBMITPROPOSAL'].fields_by_name['proposer']._loaded_options = None
  _globals['_MSGSUBMITPROPOSAL'].fields_by_name['proposer']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSUBMITPROPOSAL']._loaded_options = None
  _globals['_MSGSUBMITPROPOSAL']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\010proposer\212\347\260*\034cosmos-sdk/MsgSubmitProposal'
  _globals['_MSGSUBMITPROPOSALRESPONSE'].fields_by_name['proposal_id']._loaded_options = None
  _globals['_MSGSUBMITPROPOSALRESPONSE'].fields_by_name['proposal_id']._serialized_options = b'\352\336\037\013proposal_id\250\347\260*\001'
  _globals['_MSGVOTE'].fields_by_name['voter']._loaded_options = None
  _globals['_MSGVOTE'].fields_by_name['voter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGVOTE']._loaded_options = None
  _globals['_MSGVOTE']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\005voter\212\347\260*\022cosmos-sdk/MsgVote'
  _globals['_MSGVOTEWEIGHTED'].fields_by_name['proposal_id']._loaded_options = None
  _globals['_MSGVOTEWEIGHTED'].fields_by_name['proposal_id']._serialized_options = b'\352\336\037\013proposal_id\250\347\260*\001'
  _globals['_MSGVOTEWEIGHTED'].fields_by_name['voter']._loaded_options = None
  _globals['_MSGVOTEWEIGHTED'].fields_by_name['voter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGVOTEWEIGHTED'].fields_by_name['options']._loaded_options = None
  _globals['_MSGVOTEWEIGHTED'].fields_by_name['options']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGVOTEWEIGHTED']._loaded_options = None
  _globals['_MSGVOTEWEIGHTED']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\005voter\212\347\260*\032cosmos-sdk/MsgVoteWeighted'
  _globals['_MSGDEPOSIT'].fields_by_name['proposal_id']._loaded_options = None
  _globals['_MSGDEPOSIT'].fields_by_name['proposal_id']._serialized_options = b'\352\336\037\013proposal_id\250\347\260*\001'
  _globals['_MSGDEPOSIT'].fields_by_name['depositor']._loaded_options = None
  _globals['_MSGDEPOSIT'].fields_by_name['depositor']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGDEPOSIT'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGDEPOSIT'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_MSGDEPOSIT']._loaded_options = None
  _globals['_MSGDEPOSIT']._serialized_options = b'\210\240\037\000\350\240\037\000\200\334 \000\202\347\260*\tdepositor\212\347\260*\025cosmos-sdk/MsgDeposit'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGSUBMITPROPOSAL']._serialized_start=234
  _globals['_MSGSUBMITPROPOSAL']._serialized_end=548
  _globals['_MSGSUBMITPROPOSALRESPONSE']._serialized_start=550
  _globals['_MSGSUBMITPROPOSALRESPONSE']._serialized_end=620
  _globals['_MSGVOTE']._serialized_start=623
  _globals['_MSGVOTE']._serialized_end=785
  _globals['_MSGVOTERESPONSE']._serialized_start=787
  _globals['_MSGVOTERESPONSE']._serialized_end=804
  _globals['_MSGVOTEWEIGHTED']._serialized_start=807
  _globals['_MSGVOTEWEIGHTED']._serialized_end=1027
  _globals['_MSGVOTEWEIGHTEDRESPONSE']._serialized_start=1029
  _globals['_MSGVOTEWEIGHTEDRESPONSE']._serialized_end=1054
  _globals['_MSGDEPOSIT']._serialized_start=1057
  _globals['_MSGDEPOSIT']._serialized_end=1326
  _globals['_MSGDEPOSITRESPONSE']._serialized_start=1328
  _globals['_MSGDEPOSITRESPONSE']._serialized_end=1348
  _globals['_MSG']._serialized_start=1351
  _globals['_MSG']._serialized_end=1722
# @@protoc_insertion_point(module_scope)



from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as _msg_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgDelayMessage(_message.Message):
    __slots__ = ("authority", "msg", "delay_blocks")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    MSG_FIELD_NUMBER: _ClassVar[int]
    DELAY_BLOCKS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    msg: _any_pb2.Any
    delay_blocks: int
    def __init__(self, authority: _Optional[str] = ..., msg: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., delay_blocks: _Optional[int] = ...) -> None: ...

class MsgDelayMessageResponse(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    def __init__(self, id: _Optional[int] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from v4_proto.dydxprotocol.stats import query_pb2 as dydxprotocol_dot_stats_dot_query__pb2

GRPC_GENERATED_VERSION = '1.75.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in dydxprotocol/stats/query_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Params = channel.unary_unary(
                '/dydxprotocol.stats.Query/Params',
                request_serializer=dydxprotocol_dot_stats_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_stats_dot_query__pb2.QueryParamsResponse.FromString,
                _registered_method=True)
        self.StatsMetadata = channel.unary_unary(
                '/dydxprotocol.stats.Query/StatsMetadata',
                request_serializer=dydxprotocol_dot_stats_dot_query__pb2.QueryStatsMetadataRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_stats_dot_query__pb2.QueryStatsMetadataResponse.FromString,
                _registered_method=True)
        self.GlobalStats = channel.unary_unary(
                '/dydxprotocol.stats.Query/GlobalStats',
                request_serializer=dydxprotocol_dot_stats_dot_query__pb2.QueryGlobalStatsRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_stats_dot_query__pb2.QueryGlobalStatsResponse.FromString,
                _registered_method=True)
        self.UserStats = channel.unary_unary(
                '/dydxprotocol.stats.Query/UserStats',
                request_serializer=dydxprotocol_dot_stats_dot_query__pb2.QueryUserStatsRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_stats_dot_query__pb2.QueryUserStatsResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def Params(self, request, context):
        """Queries the Params.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StatsMetadata(self, request, context):
        """Queries StatsMetadata.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GlobalStats(self, request, context):
        """Queries GlobalStats.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UserStats(self, request, context):
        """Queries UserStats.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=dydxprotocol_dot_stats_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=dydxprotocol_dot_stats_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'StatsMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.StatsMetadata,
                    request_deserializer=dydxprotocol_dot_stats_dot_query__pb2.QueryStatsMetadataRequest.FromString,
                    response_serializer=dydxprotocol_dot_stats_dot_query__pb2.QueryStatsMetadataResponse.SerializeToString,
            ),
            'GlobalStats': grpc.unary_unary_rpc_method_handler(
                    servicer.GlobalStats,
                    request_deserializer=dydxprotocol_dot_stats_dot_query__pb2.QueryGlobalStatsRequest.FromString,
                    response_serializer=dydxprotocol_dot_stats_dot_query__pb2.QueryGlobalStatsResponse.SerializeToString,
            ),
            'UserStats': grpc.unary_unary_rpc_method_handler(
                    servicer.UserStats,
                    request_deserializer=dydxprotocol_dot_stats_dot_query__pb2.QueryUserStatsRequest.FromString,
                    response_serializer=dydxprotocol_dot_stats_dot_query__pb2.QueryUserStatsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dydxprotocol.stats.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('dydxprotocol.stats.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.stats.Query/Params',
            dydxprotocol_dot_stats_dot_query__pb2.QueryParamsRequest.SerializeToString,
            dydxprotocol_dot_stats_dot_query__pb2.QueryParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StatsMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.stats.Query/StatsMetadata',
            dydxprotocol_dot_stats_dot_query__pb2.QueryStatsMetadataRequest.SerializeToString,
            dydxprotocol_dot_stats_dot_query__pb2.QueryStatsMetadataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GlobalStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.stats.Query/GlobalStats',
            dydxprotocol_dot_stats_dot_query__pb2.QueryGlobalStatsRequest.SerializeToString,
            dydxprotocol_dot_stats_dot_query__pb2.QueryGlobalStatsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UserStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.stats.Query/UserStats',
            dydxprotocol_dot_stats_dot_query__pb2.QueryUserStatsRequest.SerializeToString,
            dydxprotocol_dot_stats_dot_query__pb2.QueryUserStatsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/authz/v1beta1/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cosmos/authz/v1beta1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from v4_proto.cosmos.authz.v1beta1 import authz_pb2 as cosmos_dot_authz_dot_v1beta1_dot_authz__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/authz/v1beta1/query.proto\x12\x14\x63osmos.authz.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a cosmos/authz/v1beta1/authz.proto\x1a\x19\x63osmos_proto/cosmos.proto\"\xbc\x01\n\x12QueryGrantsRequest\x12)\n\x07granter\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12)\n\x07grantee\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x14\n\x0cmsg_type_url\x18\x03 \x01(\t\x12:\n\npagination\x18\x04 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x7f\n\x13QueryGrantsResponse\x12+\n\x06grants\x18\x01 \x03(\x0b\x32\x1b.cosmos.authz.v1beta1.Grant\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x82\x01\n\x19QueryGranterGrantsRequest\x12)\n\x07granter\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x93\x01\n\x1aQueryGranterGrantsResponse\x12\x38\n\x06grants\x18\x01 \x03(\x0b\x32(.cosmos.authz.v1beta1.GrantAuthorization\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x82\x01\n\x19QueryGranteeGrantsRequest\x12)\n\x07grantee\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x93\x01\n\x1aQueryGranteeGrantsResponse\x12\x38\n\x06grants\x18\x01 \x03(\x0b\x32(.cosmos.authz.v1beta1.GrantAuthorization\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\xe7\x03\n\x05Query\x12\x83\x01\n\x06Grants\x12(.cosmos.authz.v1beta1.QueryGrantsRequest\x1a).cosmos.authz.v1beta1.QueryGrantsResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/cosmos/authz/v1beta1/grants\x12\xaa\x01\n\rGranterGrants\x12/.cosmos.authz.v1beta1.QueryGranterGrantsRequest\x1a\x30.cosmos.authz.v1beta1.QueryGranterGrantsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./cosmos/authz/v1beta1/grants/granter/{granter}\x12\xaa\x01\n\rGranteeGrants\x12/.cosmos.authz.v1beta1.QueryGranteeGrantsRequest\x1a\x30.cosmos.authz.v1beta1.QueryGranteeGrantsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./cosmos/authz/v1beta1/grants/grantee/{grantee}B&Z$github.com/cosmos/cosmos-sdk/x/authzb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.authz.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z$github.com/cosmos/cosmos-sdk/x/authz'
  _globals['_QUERYGRANTSREQUEST'].fields_by_name['granter']._loaded_options = None
  _globals['_QUERYGRANTSREQUEST'].fields_by_name['granter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYGRANTSREQUEST'].fields_by_name['grantee']._loaded_options = None
  _globals['_QUERYGRANTSREQUEST'].fields_by_name['grantee']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYGRANTERGRANTSREQUEST'].fields_by_name['granter']._loaded_options = None
  _globals['_QUERYGRANTERGRANTSREQUEST'].fields_by_name['granter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYGRANTEEGRANTSREQUEST'].fields_by_name['grantee']._loaded_options = None
  _globals['_QUERYGRANTEEGRANTSREQUEST'].fields_by_name['grantee']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERY'].methods_by_name['Grants']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Grants']._serialized_options = b'\202\323\344\223\002\036\022\034/cosmos/authz/v1beta1/grants'
  _globals['_QUERY'].methods_by_name['GranterGrants']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GranterGrants']._serialized_options = b'\202\323\344\223\0020\022./cosmos/authz/v1beta1/grants/granter/{granter}'
  _globals['_QUERY'].methods_by_name['GranteeGrants']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GranteeGrants']._serialized_options = b'\202\323\344\223\0020\022./cosmos/authz/v1beta1/grants/grantee/{grantee}'
  _globals['_QUERYGRANTSREQUEST']._serialized_start=194
  _globals['_QUERYGRANTSREQUEST']._serialized_end=382
  _globals['_QUERYGRANTSRESPONSE']._serialized_start=384
  _globals['_QUERYGRANTSRESPONSE']._serialized_end=511
  _globals['_QUERYGRANTERGRANTSREQUEST']._serialized_start=514
  _globals['_QUERYGRANTERGRANTSREQUEST']._serialized_end=644
  _globals['_QUERYGRANTERGRANTSRESPONSE']._serialized_start=647
  _globals['_QUERYGRANTERGRANTSRESPONSE']._serialized_end=794
  _globals['_QUERYGRANTEEGRANTSREQUEST']._serialized_start=797
  _globals['_QUERYGRANTEEGRANTSREQUEST']._serialized_end=927
  _globals['_QUERYGRANTEEGRANTSRESPONSE']._serialized_start=930
  _globals['_QUERYGRANTEEGRANTSRESPONSE']._serialized_end=1077
  _globals['_QUERY']._serialized_start=1080
  _globals['_QUERY']._serialized_end=1567
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/consensus/v1/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cosmos/consensus/v1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.tendermint.types import params_pb2 as tendermint_dot_types_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63osmos/consensus/v1/query.proto\x12\x13\x63osmos.consensus.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dtendermint/types/params.proto\"\x14\n\x12QueryParamsRequest\"H\n\x13QueryParamsResponse\x12\x31\n\x06params\x18\x01 \x01(\x0b\x32!.tendermint.types.ConsensusParams2\x8a\x01\n\x05Query\x12\x80\x01\n\x06Params\x12\'.cosmos.consensus.v1.QueryParamsRequest\x1a(.cosmos.consensus.v1.QueryParamsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cosmos/consensus/v1/paramsB0Z.github.com/cosmos/cosmos-sdk/x/consensus/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.consensus.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z.github.com/cosmos/cosmos-sdk/x/consensus/types'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\035\022\033/cosmos/consensus/v1/params'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=117
  _globals['_QUERYPARAMSREQUEST']._serialized_end=137
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=139
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=211
  _globals['_QUERY']._serialized_start=214
  _globals['_QUERY']._serialized_end=352
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from v4_proto.dydxprotocol.perpetuals import query_pb2 as dydxprotocol_dot_perpetuals_dot_query__pb2

GRPC_GENERATED_VERSION = '1.75.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in dydxprotocol/perpetuals/query_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Perpetual = channel.unary_unary(
                '/dydxprotocol.perpetuals.Query/Perpetual',
                request_serializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryPerpetualRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryPerpetualResponse.FromString,
                _registered_method=True)
        self.AllPerpetuals = channel.unary_unary(
                '/dydxprotocol.perpetuals.Query/AllPerpetuals',
                request_serializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryAllPerpetualsRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryAllPerpetualsResponse.FromString,
                _registered_method=True)
        self.AllLiquidityTiers = channel.unary_unary(
                '/dydxprotocol.perpetuals.Query/AllLiquidityTiers',
                request_serializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryAllLiquidityTiersRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryAllLiquidityTiersResponse.FromString,
                _registered_method=True)
        self.PremiumVotes = channel.unary_unary(
                '/dydxprotocol.perpetuals.Query/PremiumVotes',
                request_serializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryPremiumVotesRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryPremiumVotesResponse.FromString,
                _registered_method=True)
        self.PremiumSamples = channel.unary_unary(
                '/dydxprotocol.perpetuals.Query/PremiumSamples',
                request_serializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryPremiumSamplesRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryPremiumSamplesResponse.FromString,
                _registered_method=True)
        self.Params = channel.unary_unary(
                '/dydxprotocol.perpetuals.Query/Params',
                request_serializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryParamsResponse.FromString,
                _registered_method=True)
        self.NextPerpetualId = channel.unary_unary(
                '/dydxprotocol.perpetuals.Query/NextPerpetualId',
                request_serializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryNextPerpetualIdRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryNextPerpetualIdResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def Perpetual(self, request, context):
        """Queries a Perpetual by id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AllPerpetuals(self, request, context):
        """Queries a list of Perpetual items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AllLiquidityTiers(self, request, context):
        """Queries a list of LiquidityTiers.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PremiumVotes(self, request, context):
        """Queries a list of premium votes.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PremiumSamples(self, request, context):
        """Queries a list of premium samples.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Params(self, request, context):
        """Queries the perpetual params.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NextPerpetualId(self, request, context):
        """Queries the next perpetual id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Perpetual': grpc.unary_unary_rpc_method_handler(
                    servicer.Perpetual,
                    request_deserializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryPerpetualRequest.FromString,
                    response_serializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryPerpetualResponse.SerializeToString,
            ),
            'AllPerpetuals': grpc.unary_unary_rpc_method_handler(
                    servicer.AllPerpetuals,
                    request_deserializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryAllPerpetualsRequest.FromString,
                    response_serializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryAllPerpetualsResponse.SerializeToString,
            ),
            'AllLiquidityTiers': grpc.unary_unary_rpc_method_handler(
                    servicer.AllLiquidityTiers,
                    request_deserializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryAllLiquidityTiersRequest.FromString,
                    response_serializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryAllLiquidityTiersResponse.SerializeToString,
            ),
            'PremiumVotes': grpc.unary_unary_rpc_method_handler(
                    servicer.PremiumVotes,
                    request_deserializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryPremiumVotesRequest.FromString,
                    response_serializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryPremiumVotesResponse.SerializeToString,
            ),
            'PremiumSamples': grpc.unary_unary_rpc_method_handler(
                    servicer.PremiumSamples,
                    request_deserializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryPremiumSamplesRequest.FromString,
                    response_serializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryPremiumSamplesResponse.SerializeToString,
            ),
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'NextPerpetualId': grpc.unary_unary_rpc_method_handler(
                    servicer.NextPerpetualId,
                    request_deserializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryNextPerpetualIdRequest.FromString,
                    response_serializer=dydxprotocol_dot_perpetuals_dot_query__pb2.QueryNextPerpetualIdResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dydxprotocol.perpetuals.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('dydxprotocol.perpetuals.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def Perpetual(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.perpetuals.Query/Perpetual',
            dydxprotocol_dot_perpetuals_dot_query__pb2.QueryPerpetualRequest.SerializeToString,
            dydxprotocol_dot_perpetuals_dot_query__pb2.QueryPerpetualResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AllPerpetuals(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.perpetuals.Query/AllPerpetuals',
            dydxprotocol_dot_perpetuals_dot_query__pb2.QueryAllPerpetualsRequest.SerializeToString,
            dydxprotocol_dot_perpetuals_dot_query__pb2.QueryAllPerpetualsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AllLiquidityTiers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.perpetuals.Query/AllLiquidityTiers',
            dydxprotocol_dot_perpetuals_dot_query__pb2.QueryAllLiquidityTiersRequest.SerializeToString,
            dydxprotocol_dot_perpetuals_dot_query__pb2.QueryAllLiquidityTiersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PremiumVotes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.perpetuals.Query/PremiumVotes',
            dydxprotocol_dot_perpetuals_dot_query__pb2.QueryPremiumVotesRequest.SerializeToString,
            dydxprotocol_dot_perpetuals_dot_query__pb2.QueryPremiumVotesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PremiumSamples(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.perpetuals.Query/PremiumSamples',
            dydxprotocol_dot_perpetuals_dot_query__pb2.QueryPremiumSamplesRequest.SerializeToString,
            dydxprotocol_dot_perpetuals_dot_query__pb2.QueryPremiumSamplesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.perpetuals.Query/Params',
            dydxprotocol_dot_perpetuals_dot_query__pb2.QueryParamsRequest.SerializeToString,
            dydxprotocol_dot_perpetuals_dot_query__pb2.QueryParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def NextPerpetualId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.perpetuals.Query/NextPerpetualId',
            dydxprotocol_dot_perpetuals_dot_query__pb2.QueryNextPerpetualIdRequest.SerializeToString,
            dydxprotocol_dot_perpetuals_dot_query__pb2.QueryNextPerpetualIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
